Class: Aggregates::Event

Inherits:
DomainMessage show all
Defined in:
lib/aggregates/event.rb

Overview

The event class defines the entry point that all Events in your domain should subclass from. An Event describes something that happened. They are named in passed tense. For instance, if the user’s email has changed, then you might create an event type called UserEmailChanged.

Method Summary

Methods inherited from DomainMessage

json_create, #to_json