Class: Aggregates::EventProcessor
- Inherits:
-
Object
- Object
- Aggregates::EventProcessor
- Includes:
- MessageProcessor
- Defined in:
- lib/aggregates/event_processor.rb
Overview
EventProcessors respond to events that have occurred from Aggregates after. EventProcessors take on different roles depending on the application. The biggest role to to project aggregates as they are created and updated into a readable form for your application.
Direct Known Subclasses
Instance Method Summary collapse
Methods included from MessageProcessor
#find_message_handlers, #handle_message, included
Instance Method Details
#process_event(event) ⇒ Object
11 12 13 |
# File 'lib/aggregates/event_processor.rb', line 11 def process_event(event) event end |